import { TypeOrmModuleOptions, TypeOrmOptionsFactory } from '@nestjs/typeorm';
import { Injectable } from '@nestjs/common';
import { VaultService } from './vault/vault.service';

const envData = process.env;

@Injectable()
export class TypeOrmConfigService
  extends VaultService
  implements TypeOrmOptionsFactory {
  constructor() {
    super();
  }
  async createTypeOrmOptions(): Promise<TypeOrmModuleOptions> {

    try {
      const path = "cubbyhole/blog/database";
      const vaultData = await this.readSecret(path);
      const result = vaultData.data;
      return {
        type: 'postgres',
        host: 'postgres',
        port: 5432,
        requestTimeout: 300000,
        username: 'blog',
        password: result.password,
        database: 'blog',
        entities: [__dirname + '/entities/**/*.entity.{ts,js}'],
        synchronize: false,
        logging: true,
        logger: 'simple-console',
        migrations: [__dirname + '/migration/**/*.{ts,js}'],
        migrationsRun: true,
        extra: {
          trustServerCertificate: true,
        }
      };

    } catch (error) {
      console.error('Error fetching data from Vault:', error);
    }

  }
}
